---
name: Documentation
about: Create a report to help us improve documentation
title: 'Documentation: '
labels: documentation
assignees: k98kurz

---

### Describe the Issue

<!-- A clear and concise description of the documentation issue. -->

### Documentation Files and Sections

- readme.md: "Usage"
- dox.md: "Classes > PartialSignature"

### Discrepancies from Documentation Encountered

<!-- A clear and concise description of what discrepancies you found. -->

### Additional context

<!-- Add any other context about the problem here. -->

